@@ -1,7 +1,6 @@
-#[cfg_attr(test, macro_use)]
-extern crate may;
-
+mod token_waiter;
 mod waiter;
 mod waiter_map;
 
+pub use token_waiter::TokenWaiter;
 pub use waiter_map::{WaiterGuard, WaiterMap};
